HelpShiftPlugin class

Constructors

HelpShiftPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

openFAQsScreen({dynamic configMap}) → dynamic
method which will invoke the faq_s function implemented in Native Platform with an argument configMap , it will open the native HelpShift SDK's all FAQ screen in a web_view
openSingleFAQScreen({dynamic sectionId, dynamic configMap}) → dynamic
method which will invoke the single_faq_s function implemented in Native Platform with an argument sectionId and configMap, it will open any particular FAQ from HelpShift SDK in a web_view format
openSinglePublishedFAQDetail({dynamic publishId, dynamic configMap}) → dynamic
method which will invoke the single_faq_s function implemented in Native Platform with an argument sectionId and configMap, it will open any particular FAQ from HelpShift SDK in a web_view format
setUpHelpShiftSDK({required dynamic helpShiftApiKey, required dynamic helpShiftAppId, required dynamic helpShiftDomain}) → dynamic
call this method to setup HelpShift SDK in Native Platform with arguments helpShiftApiKey,helpShiftDomain and helpShiftAppId you will get in your HelpShift Account Dashboard
showAllConversation({dynamic configMap}) → dynamic
method which will invoke the contact_us function implemented in Native Platform with an argument configMap, it will open all the conversation listing from HelpShift SDK Support and user