showAllConversation static method

dynamic showAllConversation({
  1. dynamic configMap,
})

method which will invoke the contact_us function implemented in Native Platform with an argument configMap, it will open all the conversation listing from HelpShift SDK Support and user

Implementation

static showAllConversation({configMap}) async {
  await _channel.invokeMethod(
    Methods.allConversation,
    {'configMap': configMap},
  );
}